@@ -62,27 +62,29 @@ static char def_instr_name[256] = "";
 static char *timi_fgets(char *s, int size, FILE *fp)
 {
     int num_read = 0;
-    int newline = 0;
+    char *p = s;
 
-    while (num_read < size && !newline)
+    --size;/* so that we nul terminate properly */
+
+    for (; num_read < size; ++p)
     {
-	if (fread(&s[num_read], 1, 1, fp) != 1)
+	if (fread(p, 1, 1, fp) != 1)
 	    break;
 
+	num_read++;
+
 	/* Unlike fgets(), don't store newline. Under Windows/DOS we'll
 	 * probably get an extra blank line for every line that's being
 	 * read, but that should be ok.
 	 */
-	if (s[num_read] == '\n' || s[num_read] == '\r')
+	if (*p == '\n' || *p == '\r')
 	{
-	    s[num_read] = '\0';
-	    newline = 1;
+	    *p = '\0';
+	    return s;
 	}
-
-	num_read++;
     }
 
-    s[num_read] = '\0';
+    *p = '\0';
 
     return (num_read != 0) ? s : NULL;
 }
@@ -486,7 +488,7 @@ int mid_init(const char *config_file)
   return init_with_config(config_file);
 }
 
-static void do_song_load(MidIStream *stream, MidDLSPatches *dlspatches, MidSongOptions *options, MidSong **out)
+static void do_song_load(MidIStream *stream, MidSongOptions *options, MidSong **out)
 {
   MidSong *song;
   int i;
@@ -517,7 +519,6 @@ static void do_song_load(MidIStream *stream, MidDLSPatches *dlspatches, MidSongO
   /* Allocate memory for the song */
   song = (MidSong *)timi_calloc(sizeof(MidSong));
   if (!song) return;
-  song->dlspatches = dlspatches;
 
   for (i = 0; i < 128; i++) {
     if (master_tonebank[i]) {
@@ -608,17 +609,10 @@ fail: mid_song_free (song);
   }
 }
 
-MidSong *mid_song_load_dls(MidIStream *stream, MidDLSPatches *dlspatches, MidSongOptions *options)
-{
-  MidSong *song;
-  do_song_load(stream, dlspatches, options, &song);
-  return song;
-}
-
 MidSong *mid_song_load(MidIStream *stream, MidSongOptions *options)
 {
   MidSong *song;
-  do_song_load(stream, NULL, options, &song);
+  do_song_load(stream, options, &song);
   return song;
 }
 
@@ -694,3 +688,19 @@ long mid_get_version (void)
   return LIBTIMIDITY_VERSION;
 }
 
+/* ===== for libtimidity <= 0.2.x compatibility =====
+ */
+MidDLSPatches *mid_dlspatches_load (MidIStream *stream)
+{
+  return NULL;
+}
+
+void mid_dlspatches_free (MidDLSPatches *data)
+{
+}
+
+MidSong *mid_song_load_dls(MidIStream *stream, MidDLSPatches *dlspatches, MidSongOptions *options)
+{
+  return NULL;
+}
+
